# Burnt Ends!

A Python package containing modular, well-tested, utility and statistical functions handy for scientific computing and analysis. 

While you can install and use Burnt Ends directly, it's also a core dependency for several other packages built and used by members of the [Cosan Lab](https://www.cosanlab.org):

- [Nltools](https://nltools.org)
- [Neighbors](https://neighbors.cosanlab.org)
- [Pymer4](https://eshinjolly.com/pymer4)


## Installation

1. For the latest development release: `pip install git+https://github.com/cosanlab/burnt-ends`
2. For the latest stable release: `pip install burnt-ends`

## Documentation and Usage

Check out our [docs site](cosanlab.github.io/burnt-ends) for a full documented API!